@@ -1,15 +1,14 @@
 from .authenticator import Authenticator
 from .certs import generate_certs
 from .controller import AuthController
-from .fixture import smtpd
+from .fixture import SMTPDFix, smtpd
 from .handlers import AuthMessage
-from .smtp import AuthSMTP
 
 __all__ = (
     "AuthController",
     "Authenticator",
     "AuthMessage",
-    "AuthSMTP",
     "generate_certs",
     "smtpd",
+    "SMTPDFix",
 )
